@@ -73,16 +73,19 @@ EDITOR_PERMISSIONS = AUTHOR_PERMISSIONS + [
 MANAGEMENT_PERMISSIONS = EDITOR_PERMISSIONS + [
     "change_feedback",
     "change_imprintpage",
+    "change_organization",
     "change_pushnotification",
     "change_user",
     "change_chatmessage",
     "delete_directory",
     "delete_feedback",
     "delete_mediafile",
+    "delete_organization",
     "grant_page_permissions",
     "send_push_notification",
     "view_feedback",
     "view_imprintpage",
+    "view_organization",
     "view_pushnotification",
     "view_user",
 ]
@@ -101,6 +104,7 @@ MARKETING_TEAM_PERMISSIONS = [
     "view_organization",
     "view_page",
     "view_poi",
+    "view_poicategory",
     "view_pushnotification",
     "view_region",
     "view_user",
@@ -132,6 +136,7 @@ SERVICE_TEAM_PERMISSIONS = APP_TEAM_PERMISSIONS + [
     "change_languagetreenode",
     "change_offertemplate",
     "change_organization",
+    "change_poicategory",
     "change_user",
     "delete_chatmessage",
     "delete_directory",
@@ -140,8 +145,10 @@ SERVICE_TEAM_PERMISSIONS = APP_TEAM_PERMISSIONS + [
     "delete_imprintpage",
     "delete_languagetreenode",
     "delete_offertemplate",
+    "delete_organization",
     "delete_page",
     "delete_poi",
+    "delete_poicategory",
     "delete_pushnotification",
     "delete_region",
     "delete_user",
