@@ -19,7 +19,7 @@ class LinkcheckStatsView(View):
         Retrieve the stats about valid/invalid/unchecked/ignored links
 
         :param request: The current request
-        :type request: ~django.http.HttpResponse
+        :type request: ~django.http.HttpRequest
 
         :param \*args: The supplied arguments
         :type \*args: list
