@@ -28,7 +28,7 @@ class AnalyticsView(TemplateView):
         Render statistics of access numbers tracked by Matomo
 
         :param request: The current request
-        :type request: ~django.http.HttpResponse
+        :type request: ~django.http.HttpRequest
 
         :param \*args: The supplied arguments
         :type \*args: list
