@@ -41,6 +41,7 @@ VIEWS = [
             ("new_role", [ROOT]),
             ("new_user", STAFF_ROLES),
             ("offertemplates", STAFF_ROLES),
+            ("poicategories", STAFF_ROLES),
             ("regions", STAFF_ROLES),
             ("roles", [ROOT]),
             ("user_settings", STAFF_ROLES),
@@ -99,8 +100,8 @@ VIEWS = [
             ("region_feedback", STAFF_ROLES + [MANAGEMENT]),
             ("region_users", STAFF_ROLES + [MANAGEMENT]),
             ("translation_coverage", ROLES),
-            ("organizations", STAFF_ROLES),
-            ("new_organization", STAFF_ROLES),
+            ("organizations", STAFF_ROLES + [MANAGEMENT]),
+            ("new_organization", STAFF_ROLES + [MANAGEMENT]),
             ("user_settings", ROLES),
             ("authenticate_modify_mfa", ROLES),
         ],
@@ -360,6 +361,35 @@ VIEWS = [
         # The kwargs for these views
         {"slug": "ihk-lehrstellenboerse"},
     ),
+    (
+        [("edit_poicategory", STAFF_ROLES)],
+        # The kwargs for these views
+        {"pk": 1},
+    ),
+    (
+        [
+            (
+                "edit_poicategory",
+                HIGH_PRIV_STAFF_ROLES,
+                {
+                    "translations-TOTAL_FORMS": 2,
+                    "translations-INITIAL_FORMS": 2,
+                    "translations-MIN_NUM_FORMS": 2,
+                    "translations-MAX_NUM_FORMS": 2,
+                    "translations-0-id": 1,
+                    "translations-0-category": 1,
+                    "translations-0-language": 1,
+                    "translations-0-name": "Test Kategorie",
+                    "translations-1-id": 2,
+                    "translations-1-category": 1,
+                    "translations-1-language": 2,
+                    "translations-1-name": "Test category",
+                },
+            )
+        ],
+        # The kwargs for these views
+        {"pk": 1},
+    ),
     (
         [("linkcheck", ROLES)],
         # The kwargs for these views
@@ -807,16 +837,16 @@ if settings.FCM_ENABLED:
                     "new_push_notification",
                     PRIV_STAFF_ROLES + [MANAGEMENT],
                     {
-                        "form-TOTAL_FORMS": 2,
-                        "form-INITIAL_FORMS": 0,
-                        "form-MIN_NUM_FORMS": 1,
-                        "form-MAX_NUM_FORMS": 2,
-                        "form-0-title": "Test title",
-                        "form-0-text": "Test content",
-                        "form-0-language": 1,
-                        "form-1-title": "",
-                        "form-1-text": "",
-                        "form-1-language": 6,
+                        "translations-TOTAL_FORMS": 2,
+                        "translations-INITIAL_FORMS": 0,
+                        "translations-MIN_NUM_FORMS": 1,
+                        "translations-MAX_NUM_FORMS": 2,
+                        "translations-0-title": "Test title",
+                        "translations-0-text": "Test content",
+                        "translations-0-language": 1,
+                        "translations-1-title": "",
+                        "translations-1-text": "",
+                        "translations-1-language": 6,
                         "channel": "news",
                         "mode": "ONLY_AVAILABLE",
                     },
